/*-
 * %%----------------------------------------------------------------------------------------------
 * Archive ouverte UNIGE - AoU Access - AccessDownloadTokenController.java
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2022 - 2023 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

package ch.unige.aou.controller.access;

import java.net.URI;
import java.net.URISyntaxException;

import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RestController;

import ch.unige.solidify.rest.ActionName;

import ch.unige.aou.config.AouProperties;
import ch.unige.aou.controller.AccessController;
import ch.unige.aou.model.settings.DownloadToken;
import ch.unige.aou.rest.ResourceName;
import ch.unige.aou.rest.UrlPath;
import ch.unige.aou.service.DownloadTokenService;

@RestController
@ConditionalOnBean(AccessController.class)
public class AccessDownloadTokenController {

  private final DownloadTokenService downloadTokenService;
  private final String accessModulePath;

  public AccessDownloadTokenController(AouProperties aouProperties, DownloadTokenService downloadTokenService) throws URISyntaxException {
    this.downloadTokenService = downloadTokenService;
    this.accessModulePath = new URI(aouProperties.getModule().getAccess().getPublicUrl()).getPath();
  }

  @GetMapping(UrlPath.ACCESS_METADATA + "/{archiveId}/" + ActionName.DOWNLOAD_TOKEN)
  @PreAuthorize("@publicationDownloadPermissionService.isAllowed(#archiveId, 'DOWNLOAD_FILE')")
  public ResponseEntity<DownloadToken> getTokenForArchive(@PathVariable String archiveId) {
    final String cookiePath = this.accessModulePath + "/" + ResourceName.METADATA + "/" + archiveId + "/" + ActionName.DOWNLOAD;
    return new ResponseEntity<>(this.downloadTokenService.getHeadersWithToken(archiveId, cookiePath), HttpStatus.OK);

  }

}
