/*-
 * %%----------------------------------------------------------------------------------------------
 * Archive ouverte UNIGE - AoU Solution - SolutionRestTestsAndDocumentation.java
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2022 - 2023 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

package ch.unige.aou.test.doc;

import org.junit.jupiter.api.extension.ExtendWith;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.context.SpringBootTest.WebEnvironment;
import org.springframework.context.annotation.Import;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.junit.jupiter.SpringExtension;

import ch.unige.solidify.IndexUrlPath;
import ch.unige.solidify.OAIUrlPath;
import ch.unige.solidify.test.doc.RestDocsDocumentation;

import ch.unige.aou.rest.UrlPath;
import ch.unige.aou.test.resource.ApplicationRoleDoc;
import ch.unige.aou.test.resource.ContributorDoc;
import ch.unige.aou.test.resource.DocumentFileTypeDoc;
import ch.unige.aou.test.resource.EventDoc;
import ch.unige.aou.test.resource.GlobalBannerDoc;
import ch.unige.aou.test.resource.IndexFieldAliasDoc;
import ch.unige.aou.test.resource.InstitutionDoc;
import ch.unige.aou.test.resource.LanguageDoc;
import ch.unige.aou.test.resource.LicenseDoc;
import ch.unige.aou.test.resource.LicenseGroupDoc;
import ch.unige.aou.test.resource.MetadataDoc;
import ch.unige.aou.test.resource.ModuleDoc;
import ch.unige.aou.test.resource.NotificationDoc;
import ch.unige.aou.test.resource.OaiMetadataPrefixDoc;
import ch.unige.aou.test.resource.OaiSetDoc;
import ch.unige.aou.test.resource.PersonDoc;
import ch.unige.aou.test.resource.PublicationDoc;
import ch.unige.aou.test.resource.PublicationDownloadDoc;
import ch.unige.aou.test.resource.PublicationTypeDoc;
import ch.unige.aou.test.resource.ResearchGroupDoc;
import ch.unige.aou.test.resource.RoleDoc;
import ch.unige.aou.test.resource.StructureDoc;
import ch.unige.aou.test.resource.SystemPropertyDoc;
import ch.unige.aou.test.resource.UserDoc;

@ActiveProfiles({ "test", "sec-noauth", "person-search-aou-prod", "client-standalone", "storage-file", "index-inmemory" })
@ExtendWith(SpringExtension.class)
@Import(SolutionRestTestsAndDocumentationConfig.class)
@SpringBootTest(webEnvironment = WebEnvironment.DEFINED_PORT, properties = { "spring.cloud.bootstrap.enabled=true" })
public class SolutionRestTestsAndDocumentation extends RestDocsDocumentation {

  @Override
  protected void loadResources() {
    this.addResources(new InstitutionDoc());
    this.addResources(new LanguageDoc());
    this.addResources(new LicenseDoc());
    this.addResources(new LicenseGroupDoc());
    this.addResources(new ModuleDoc());
    this.addResources(new MetadataDoc());
    this.addResources(new PersonDoc());
    this.addResources(new PublicationDoc());
    this.addResources(new PublicationTypeDoc());
    this.addResources(new ApplicationRoleDoc());
    this.addResources(new SystemPropertyDoc());
    this.addResources(new UserDoc());
    this.addResources(new ResearchGroupDoc());
    this.addResources(new RoleDoc());
    this.addResources(new StructureDoc());
    this.addResources(new EventDoc());
    this.addResources(new NotificationDoc());
    this.addResources(new ContributorDoc());
    this.addResources(new DocumentFileTypeDoc());
    this.addResources(new GlobalBannerDoc());
    this.addResources(new PublicationDownloadDoc());
    this.addResources(new IndexFieldAliasDoc());
    this.addResources(new OaiMetadataPrefixDoc());
    this.addResources(new OaiSetDoc());
  }

  @Override
  protected void setUrlIgnoreList() {
    // Admin
    this.urlIgnoreList.add(this.getContextPath() + UrlPath.ADMIN_MONITOR);
    this.urlIgnoreList.add(this.getContextPath() + UrlPath.ADMIN_NOTIFICATION_TYPES);
    this.urlIgnoreList.add(this.getContextPath() + UrlPath.ADMIN_CONTRIBUTOR_ROLE);
    this.urlIgnoreList.add(this.getContextPath() + UrlPath.ADMIN_SCHEDULED_TASKS);
    this.urlIgnoreList.add(this.getContextPath() + UrlPath.ADMIN_DOCUMENT_FILES);
    this.urlIgnoreList.add(this.getContextPath() + UrlPath.ADMIN_PUBLICATION_SUBTYPES);
    this.urlIgnoreList.add(this.getContextPath() + UrlPath.ADMIN_STORED_SEARCHES);
    // Access
    this.urlIgnoreList.add(this.getContextPath() + OAIUrlPath.OAI_PROVIDER);
    // Index
    this.urlIgnoreList.add(this.getContextPath() + IndexUrlPath.INDEX_SETTING);
    this.urlIgnoreList.add(this.getContextPath() + IndexUrlPath.INDEX_INDEX);
  }

  @Override
  protected void setUrlReadOnlyList() {
    // Admin
    this.urlReadOnlyList.add(this.getContextPath() + UrlPath.ADMIN_SYSTEM_PROPERTIES);
    this.urlReadOnlyList.add(this.getContextPath() + UrlPath.ADMIN_MODULES);
    // Access
    this.urlReadOnlyList.add(this.getContextPath() + UrlPath.ACCESS_METADATA);
  }
}
